/*
 *  \file      demo_ff.h
 *  \brief     Demo routine to test write to and read from the SD-card
 *  \date      11-03-2020 
 *  \version   1.5 
 */ 
#include <stdio.h>
#include "ff/ff.h"

char    buffer[256];

FATFS FatFs;           // FatFs work area needed for each volume
FIL   Fil;             // File object needed for each open file

/*! \brief  Demonstration. It writes text to a file on the SD-card. After that it reads the
 *          file from the SD-card and print the text.
 *          This example is code D.2 from 'De taal C en de Xmega' second edition,
 *          see <a href="http://www.dolman-wim.nl/xmega/book/index.php">Voorbeelden uit 'De taal C en de Xmega'</a>
 *
 *  \return void
 */

int demo_ff(void)
{
  UINT    bw;
  uint8_t ret;

  printf("Demo FatFs\n");
  if ( (ret = f_mount(&FatFs, "", 1)) != FR_OK ) {
    printf("Demo aborted: device not found\n");
    return ret;
  }

  // create and write file demo.txt
  if ((ret = f_open(&Fil, "demo.txt", FA_WRITE|FA_CREATE_ALWAYS)) != FR_OK) {
    printf("Demo aborted: can't create file\n");
    return ret;
  }

  printf("DEMO : write file\n");
  f_write(&Fil, "Some text written!\r\n", 20, &bw);
  f_printf(&Fil, "Printf %s\n", "works as well");
  f_printf(&Fil, "Variabele bw is %d", bw);

  f_close(&Fil);

  // read file demo.txt
  if ((ret = f_open(&Fil, "demo.txt", FA_READ)) != FR_OK) {
    printf("Demo aborted: can't open file\n");
    return ret;
  }

  while ( f_gets(buffer, 255, &Fil) != NULL ) {
    printf("\txx%s", buffer);
  }

  f_close(&Fil);

  return FR_OK;
}